# Cli

Package with utilities to interact with the command line interface:
* Output interactions
* Input interactions
* Running processes

## Installation

```shell
pip install git+https://github.com/quintenroets/cli
```

## Usage
Use 

```shell
import cli
```
instead of

```shell
import subprocess
```

to run processes
